@@ -8,13 +8,31 @@ from pathlib import Path as __Path
 from django.utils.translation import ugettext_lazy as _
 
 
-# Build paths relative to the current working directory:
-BASE_PATH = __Path().cwd().resolve()
-print(f'BASE_PATH:{BASE_PATH}')
-
+###############################################################################
 
 # Build paths relative to the project root:
 PROJECT_PATH = __Path(__file__).parent.parent.parent
+print(f'PROJECT_PATH:{PROJECT_PATH}')
+
+if __Path('/.dockerenv').is_file():
+    # We are inside a docker container
+    BASE_PATH = __Path('/django_volumes')
+    assert BASE_PATH.is_dir()
+else:
+    # Build paths relative to the current working directory:
+    BASE_PATH = __Path().cwd().resolve()
+
+print(f'BASE_PATH:{BASE_PATH}')
+
+# Paths with Django dev. server:
+# BASE_PATH...: .../django-for-runners
+# PROJECT_PATH: .../django-for-runners/src
+#
+# Paths in Docker container:
+# BASE_PATH...: /for_runners_volumes
+# PROJECT_PATH: /usr/local/lib/python3.9/site-packages
+
+###############################################################################
 
 
 # SECURITY WARNING: don't run with debug turned on in production!
